import os
import csv
from datetime import datetime, timedelta

# Get today's and yesterday's date
today = datetime.now().strftime("%d_%m")
yesterday = (datetime.now() - timedelta(days=1)).strftime("%d_%m")

# Subfolder name
subfolder = "csv_files"

# File names
today_file = os.path.join(subfolder, f"final_csv_{today}.csv")
yesterday_file = os.path.join(subfolder, f"final_csv_{yesterday}.csv")

# Dictionary to store prices and quantities from yesterday's file
yesterday_data = {}

# Read yesterday's file and store data in the dictionary
with open(yesterday_file, 'r') as file:
    reader = csv.reader(file)
    next(reader)  # Skip header
    for row in reader:
        sku = row[0]
        price = row[1]
        qty = row[2]
        yesterday_data[sku] = (price, qty)

# Create a new CSV file for today's data with the additional columns
output_file = 'csv_files/final_csv_with_diff.csv'
with open(today_file, 'r') as file:
    with open(output_file, 'w', newline='') as output:
        reader = csv.reader(file)
        writer = csv.writer(output)
        header = next(reader)
        header.extend(["Previous Price", "Price Difference (%)"])
        writer.writerow(header)

        for row in reader:
            sku = row[0]
            price = row[1]
            qty = row[2]
            if sku in yesterday_data:
                yesterday_price, _ = yesterday_data[sku]
                try:
                    price = float(price)
                    yesterday_price = float(yesterday_price)
                    price_diff = ((price - yesterday_price) / yesterday_price) * 100
                    row.extend([yesterday_price, price_diff])
                except ValueError:
                    row.extend(["Value not found", "Value not found"])
            else:
                row.extend(["Value not found", "Value not found"])
            writer.writerow(row)

print("Price differences calculated and saved in", output_file)
